==> foundry_platform_sdk-0.84.0.tar.gz: foundry_platform_sdk-0.84.0/foundry/v2/admin/errors/_cannot_replace_provider_info_for_principal_in_protected_realm.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

import pydantic
from typing_extensions import TypedDict

from foundry._errors import PalantirRPCException
from foundry.v2.core.models._principal_id import PrincipalId
from foundry.v2.core.models._realm import Realm


class CannotReplaceProviderInfoForPrincipalInProtectedRealmParameters(TypedDict):
    """Provider information for Principals in this Realm cannot be replaced."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    principalId: PrincipalId

    realm: Realm


@dataclass
class CannotReplaceProviderInfoForPrincipalInProtectedRealm(PalantirRPCException):
    name: Literal["CannotReplaceProviderInfoForPrincipalInProtectedRealm"]
    parameters: CannotReplaceProviderInfoForPrincipalInProtectedRealmParameters
    error_instance_id: str


__all__ = ["CannotReplaceProviderInfoForPrincipalInProtectedRealm"]

==> foundry_platform_sdk-0.91.0.tar.gz: foundry_platform_sdk-0.91.0/foundry/v2/admin/errors/_cannot_replace_provider_info_for_principal_in_protected_realm.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from dataclasses import dataclass
from typing import Literal

from typing_extensions import TypedDict

from foundry._errors import BadRequestError
from foundry.v2.core.models._principal_id import PrincipalId
from foundry.v2.core.models._realm import Realm


class CannotReplaceProviderInfoForPrincipalInProtectedRealmParameters(TypedDict):
    """Provider information for Principals in this Realm cannot be replaced."""

    __pydantic_config__ = {"extra": "allow"}  # type: ignore

    principalId: PrincipalId

    realm: Realm


@dataclass
class CannotReplaceProviderInfoForPrincipalInProtectedRealm(BadRequestError):
    name: Literal["CannotReplaceProviderInfoForPrincipalInProtectedRealm"]
    parameters: CannotReplaceProviderInfoForPrincipalInProtectedRealmParameters
    error_instance_id: str


__all__ = ["CannotReplaceProviderInfoForPrincipalInProtectedRealm"]
